class Configuration:

    def __init__(self):
        return None;
    
    def setEnvironment(self, environment):
        self.__environment = environment
    
    def getEnvironment(self):
        return self.__environment
    
    def setCommerceCode(self, commercecode):
        self.__commercecode = commercecode
        
    def getCommerceCode(self):
        return self.__commercecode
    
    def setPrivateKey(self, privatekey):
        self.__privatekey = privatekey
    
    def getPrivateKey(self):
        return self.__privatekey
    
    def setPublicCert(self, publiccert):
        self.__publiccert = publiccert
        
    def getPublicCert(self):
        return self.__publiccert
        
    def setWebpayCert(self, webpaycert):
        self.__webpaycert = webpaycert
        
    def getWebPayCert(self):
        return self.__webpaycert
    
    def setStoreCodes(self, storecodes):
        self.__storecodes = storecodes
        
    def getStoreCodes(self):
        return self.__storecodes
    
    def getEnvironmentDefault(self):
        modo = self.__environment
        if (modo == None or modo == ""):
            modo = "INTEGRACION"
        return modo


"""
@author     Allware Ltda. (http://www.allware.cl)
@copyright  2016 Transbank S.A. (http://www.tranbank.cl)
@date       Jan 2015
@license    GNU LGPL
@version    2.0.1
"""
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.http import HttpResponse
import socket

from oscar_webpay.certificates import cert_normal

from suds.client import Client
from suds.wsse import Security, Timestamp
from wsse.suds import WssePlugin

from suds.transport.https import HttpTransport
import logging

from decimal import *

from oscar_webpay.oscar_webpay_settings import OscarWebpaySettingError

logging.basicConfig()

config = None
url = None


class Dictionaries():
    """
	Configuracion de WSDL segun ambiente
	"""

    @staticmethod
    def dictionaryConfig():
        normal_config = getattr(settings, 'WEBPAY_COMPLETE', None)
        config = normal_config.get('ENVIRONMENTS', None)
        if config is None:
            raise OscarWebpaySettingError(_('You must provide the ENVIRONMENTS variable for the settings'))

        return config


class WebpayComplete():
    def __init__(self, configuration):

        global config
        config = configuration
        self.__config = config

        dictWsdl = Dictionaries.dictionaryConfig()

        global url
        url = dictWsdl[self.__config.getEnvironment()]
        self.__url = url

    """
        Permite solicitar a Webpay la anulacion de una transaccion realizada previamente y que se encuentra vigente.
        """

    @staticmethod
    def initCompleteTransaction(amount, buyOrder, sessionId, cardExpirationdate, cvv, cardNumber):

        client = WebpayComplete.get_client(url, config.getPrivateKey(), config.getPublicCert(), config.getWebPayCert())
        client.options.cache.clear()

        wsCompleteInitTransactionInput = client.factory.create('wsCompleteInitTransactionInput')

        wsCompleteTransactionDetail = client.factory.create('wsCompleteTransactionDetail')

        completeCardDetail = client.factory.create('completeCardDetail')

        wsCompleteInitTransactionInput.transactionType = client.factory.create(
            'wsCompleteTransactionType').TR_COMPLETA_WS
        wsCompleteInitTransactionInput.sessionId = sessionId

        wsCompleteTransactionDetail.amount = amount
        wsCompleteTransactionDetail.buyOrder = buyOrder
        wsCompleteTransactionDetail.commerceCode = config.getCommerceCode()

        completeCardDetail.cardExpirationDate = cardExpirationdate
        completeCardDetail.cvv = cvv
        completeCardDetail.cardNumber = cardNumber

        wsCompleteInitTransactionInput.cardDetail = completeCardDetail

        wsCompleteInitTransactionInput.transactionDetails = wsCompleteTransactionDetail

        try:
            wsCompleteInitTransactionOutput = client.service.initCompleteTransaction(wsCompleteInitTransactionInput)
        except Exception as e:
            print str(e)

        return wsCompleteInitTransactionOutput

    """
	Permite realizar consultas del valor de cuotas (producto nuevas cuotas)
	"""

    @staticmethod
    def queryshare(token, buyOrder, shareNumber):

        client = WebpayComplete.get_client(url, config.getPrivateKey(), config.getPublicCert(), config.getWebPayCert())
        client.options.cache.clear()

        wsCompleteQueryShareInput = client.factory.create('wsCompleteQueryShareInput')

        try:
            wsCompleteQuerySharesOutput = client.service.queryShare(token, buyOrder, int(shareNumber))
        except Exception as e:
            print str(e)

        return wsCompleteQuerySharesOutput

    """
	Ejecuta la solicitud de autorizacion, esta puede ser realizada con o sin cuotas. La respuesta entrega el resultado de la transaccion.
	"""

    @staticmethod
    def authorize(token, buyOrder, gracePeriod, idQueryShare, deferredPeriodIndex):

        client = WebpayComplete.get_client(url, config.getPrivateKey(), config.getPublicCert(), config.getWebPayCert())
        client.options.cache.clear()

        authorize = client.factory.create('authorize')

        wsCompletePaymentTypeInput = client.factory.create('wsCompletePaymentTypeInput')

        wsCompleteQueryShareInput = client.factory.create('wsCompleteQueryShareInput')

        authorize.token = token

        wsCompletePaymentTypeInput.buyOrder = buyOrder
        wsCompletePaymentTypeInput.commerceCode = config.getCommerceCode()
        wsCompletePaymentTypeInput.gracePeriod = gracePeriod

        wsCompleteQueryShareInput.idQueryShare = idQueryShare;

        if (deferredPeriodIndex != 0):
            wsCompleteQueryShareInput.deferredPeriodIndex = deferredPeriodIndex

        wsCompletePaymentTypeInput.queryShareInput = wsCompleteQueryShareInput

        authorize.paymentTypeList = wsCompletePaymentTypeInput

        try:
            wsCompleteAuthorizeOutput = client.service.authorize(token, wsCompletePaymentTypeInput)
            acknowledge = WebpayComplete.acknowledgeTransaction(token)
        except Exception as e:
            print str(e)

        return wsCompleteAuthorizeOutput

    """
	acknowledgeTransaction
	Indica a Webpay que se ha recibido conforme el resultado de la transaccion
	"""

    @staticmethod
    def acknowledgeTransaction(token):

        client = WebpayComplete.get_client(url, config.getPrivateKey(), config.getPublicCert(), config.getWebPayCert())
        client.options.cache.clear()

        acknowledge = client.service.acknowledgeCompleteTransaction(token)

        return acknowledge

    @staticmethod
    def get_client(wsdl_url, our_keyfile_path, our_certfile_path, their_certfile_path):

        transport = HttpTransport()
        wsse = Security()

        return Client(
            wsdl_url,
            transport=transport,
            wsse=wsse,
            plugins=[
                WssePlugin(
                    keyfile=our_keyfile_path,
                    certfile=our_certfile_path,
                    their_certfile=their_certfile_path,
                ),
            ],
        )



#! -*- coding: utf-8 -*-
from constance import config
import datetime
import uuid

from django.http import Http404
from django.http import HttpResponseRedirect

from django.shortcuts import redirect, render
from django.utils import six
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext
from django.contrib import messages
from django.template import RequestContext
from django.utils.decorators import method_decorator
from django.views.decorators.csrf import csrf_exempt
from django.views.generic import View, RedirectView, TemplateView, DetailView
from django.core.urlresolvers import reverse

from oscar.core.loading import get_class, get_model, get_classes
from oscar_webpay.gateway import get_webpay_client, confirm_transaction

import decimal

# Load views dynamically
PaymentDetailsView = get_class('checkout.views', 'PaymentDetailsView')
CheckoutSessionMixin = get_class('checkout.session', 'CheckoutSessionMixin')
Selector = get_class('partner.strategy', 'Selector')

SourceType = get_model('payment', 'SourceType')
Source = get_model('payment', 'Source')
Transaction = get_model('payment', 'Transaction')
Order = get_model('order', 'Order')
Basket = get_model('basket', 'Basket')

OrderCreator = get_class('order.utils', 'OrderCreator')

RedirectRequired, UnableToTakePayment, PaymentError \
    = get_classes('payment.exceptions', ['RedirectRequired',
                                         'UnableToTakePayment',
                                         'PaymentError'])


class WebPayRedirect(CheckoutSessionMixin, RedirectView):
    as_payment_method = False

    def get_redirect_url(self, *args, **kwargs):
        return reverse('webpay-details')


class WebPayForm(TemplateView):
    template_name = 'checkout/webpay_form.html'

    def get_context_data(self, **kwargs):
        ctx = super(WebPayForm, self).get_context_data(**kwargs)
        ctx.update({
            'payment_url': self.request.session['payment_url'],
            'token_ws': self.request.session['token']
        })
        return ctx


@method_decorator(csrf_exempt, name='dispatch')
class WebPayPaymentDetailsView(PaymentDetailsView):
    template_name = 'checkout/payment_details.html'
    template_name_preview = 'checkout/webpay_preview.html'

    preview = True
    payment_mode = False

    def get_context_data(self, **kwargs):
        ctx = super(WebPayPaymentDetailsView, self).get_context_data(**kwargs)
        try:

            basket = self.build_submission()['basket']
            total = basket.total_incl_tax
            try:
                # Some customizations use shipping charge.
                total = basket.total_incl_tax + decimal.Decimal(ctx['shipping_charge'].incl_tax)
            except AttributeError:
                pass

            transaction = get_webpay_client(basket.pk, total)

            ctx['payment_url'] = reverse('webpay-details')
            ctx['token_ws'] = transaction['token']
            ctx['payment_method_webpay'] = True

            self.request.session['total'] = total
            self.request.session['order_number'] = basket.pk
            self.request.session['payment_url'] = transaction['url']
            self.request.session['token'] = ctx['token_ws']
            self.request.session['shipping_charge'] = ctx['shipping_charge'].incl_tax

            pass
        except Exception as wpe:
            messages.error(self.request, wpe.message)
        else:
            return ctx

    def post(self, request, *args, **kwargs):
        error_msg = _(
            u"A problem occurred communicating with WebPay "
            u"- please try again later"
        )

        try:
            self.token = request.POST['token_ws']
        except KeyError:
            # Probably suspicious manipulation if we get here
            messages.error(self.request, error_msg)
            return HttpResponseRedirect(reverse('basket:summary'))

        submission = self.build_submission(**kwargs)
        self.request.session['total'] = submission["order_total"]

        if not self.payment_mode:
            basket = kwargs.get('basket', self.request.basket)
            shipping_address = self.get_shipping_address(basket)
            shipping_method = self.get_shipping_method(
                basket, shipping_address)
            billing_address = self.get_billing_address(shipping_address)


            if not shipping_method:
                total = shipping_charge = None
            else:
                shipping_charge = shipping_method.calculate(basket)
                total = self.get_order_totals(
                    basket, shipping_charge=shipping_charge)
            order_number = self.generate_order_number(basket)

            try:
                order = Order.objects.get(number=order_number)
            except Order.DoesNotExist:
                # Place the order.
                order = self.place_order(
                    order_number=order_number, user=request.user, basket=basket,
                    shipping_address=shipping_address,
                    shipping_method=shipping_method,
                    shipping_charge=shipping_charge,
                    order_total=total,
                    billing_address=billing_address,
                    **(submission['order_kwargs'])
                )
            finally:
                # Add Payment envents.
                source_type, is_created = SourceType.objects.get_or_create(name='WebPay')

                source = Source(
                    source_type=source_type,
                    currency=submission["order_total"].currency,
                    amount_allocated=submission["order_total"].incl_tax,
                )


                self.add_payment_source(source)
                self.add_payment_event(_(u'Confirmation pending'), submission["order_total"].incl_tax)
                self.save_payment_details(order)

                self.request.session['oscar_webpay_source_id'] = source.id

            return redirect('webpay-form')
        return self.submit(**submission)

    def get(self, request):
        payment_method = self.checkout_session.payment_method()
        return self.render_preview(request, payment_method=payment_method)

    def build_submission(self, **kwargs):
        submission = super(WebPayPaymentDetailsView, self).build_submission()
        if hasattr(self, 'token'):
            # Execute this only when not in preview mode.
            submission['payment_kwargs']['token'] = self.token
            # Set the initial state of payment to In process':
            # TODO: Make correct translation here.
            submission['order_kwargs']['status'] = _(u"Confirmation pending")
            submission['order_kwargs']['client_desired_dispatch_date'] = dispath_date = datetime.datetime.strptime(
                self.checkout_session.get_shipping_date(), "%d/%m/%Y"
            ).date()
            submission["order_kwargs"]["client_desired_dispatch_time"] = self.checkout_session.get_shipping_time()
        return submission

    def submit(self, **submission):
        return super(WebPayPaymentDetailsView, self).submit(**submission)

    def handle_order_placement(self, order_number, user, basket, shipping_address, shipping_method,
                               shipping_charge, billing_address, order_total, **order_kwargs):

        # This is really a crap!!  But I'm working right now on top
        # of a legacy work and the time line is short. I swear I'll be
        # comback to this code latter!!!!
        order = Order.objects.get(number=order_number)
        # self.save_payment_details(order)
        if self.order_status_value == 1:
            # Some thing was wrong with payment.
            return redirect("basket:summary")
        else:
            return self.handle_successful_order(order)


    def handle_payment(self, order_number, total, **kwargs):
        try:
            result = confirm_transaction(kwargs['token'])
        except Exception as wpe:
            raise PaymentError(six.text_type(wpe))
        else:
            source_type, is_created = SourceType.objects.get_or_create(name='WebPay')
            # source = Source(
            #     source_type=source_type,
            #     currency=self.request.session['total'].currency,
            #     amount_allocated=self.request.session['total'].incl_tax,
            # )
            respCode = result.detailOutput[0]['responseCode']
            if (result['VCI'] == 'TSY' or result['VCI'] == '') and respCode == 0:
                source = Source.objects.get(id=self.request.session['oscar_webpay_source_id'])
                source.amount_debited = total.incl_tax
                source.save()
                self.add_payment_source(source)
                self.add_payment_event(_(u'Confirmed'), total.incl_tax)
                order = Order.objects.get(number=order_number)
                order.status = _(u'Confirmed')
                order.save()
                self.save_payment_details(order)
                self.order_status_value = 0

                # Creating the transaction for successful payment.
                Transaction.objects.create(
                    source=source,
                    amount=result.detailOutput[0].amount,
                    status=_(u"Confirmed"),
                    reference=str(uuid.uuid4())
                )
            else:
                messages.error(
                    self.requets,
                   _(u"A problem occurred communicating with WebPay - please try again later")
                )
                self.order_status_value = 1
            return None

@method_decorator(csrf_exempt, name='dispatch')
class WebPaySuccessView(TemplateView):
    template_name = "checkout/payment_success.html"

    def get_context_data(self, **kwargs):
        ctx = super(WebPaySuccessView, self).get_context_data(**kwargs)
        order = ctx.get("order")
        lines = order.lines.all()
        products = []

        recomended = False
        for l in lines:
            product = l.product
            # products.append(l.product)
            if product.is_standalone or product.is_standalone:
                for p in product.recommended_products.all():
                    products.append(p)
            elif product.is_child:
                for p in product.parent.recommended_products.all():
                    products.append(p)

        if len(products) > 0:
            recomended = True

        basket = self.order.basket
        basket.strategy = Selector().strategy(self.request)

        ctx['recomended'] = recomended
        ctx['products'] = products
        ctx['lines'] = lines
        ctx['basket'] = basket
        # TODO: this is a dependence, refactor later.
        ctx['address'] = config.BUSINESS_ADDRESS

        return ctx

@method_decorator(csrf_exempt, name='dispatch')
class WebPayCancel(View):
    def post(self, request, *args, **kwargs):
        return redirect('basket:summary')

@method_decorator(csrf_exempt, name='dispatch')
class WebPayFail(View):
    template_name = "checkout/payment_fail.html"

    def get_context_data(self, **kwargs):
        ctx = super(WebPayFail, self).get_context_data(**kwargs)
        return ctx


@method_decorator(csrf_exempt, name='dispatch')
class WebPayThankYouView(View):
    """
    Displays the 'thank you' page which summarises the order just submitted.
    """
    template_name = 'checkout/thank_you.html'

    def post(self, request, *args, **kwargs):
        return render(request, 'checkout/thank_you.html', context={}, context_instance=RequestContext(request))

    def get(self, request, *args, **kwargs):
        pass



from django.views import generic
from django.conf import settings

from oscar_webpay import models


class TransactionListView(generic.ListView):
    model = models.WebPayTransaction
    template_name = 'oscar_webpay/dashboard/transaction_list.html'
    context_object_name = 'transactions'



class TransactionDetailView(generic.DetailView):
    model = models.WebPayTransaction
    template_name = 'oscar_webpay/dashboard/transaction_detail.html'
    context_object_name = 'txn'

    def get_context_data(self, **kwargs):
        ctx = super(TransactionDetailView, self).get_context_data(**kwargs)
        return ctx


import logging
import os

from django.conf import settings
from django.conf import LazyObject
from django.utils.translation import ugettext_lazy as _


logger = logging.getLogger('oscar_webpay')


class OscarWebpaySettingError(Exception):
    pass


class OscarWebpaySettings(object):

    def __init__(self):

        # As oscar payment flow is defined, an order is only placed after payment
        # completion. Set `PLACE_ORDER_BEFORE_TAKE_PAYMENT` to True in order to
        # place an order BEFORE payment submission.
        # This can be handy when you want to track client payment intents, even if payment fails.
        self.PLACE_ORDER_BEFORE_TAKE_PAYMENT = getattr(settings, 'PLACE_ORDER_BEFORE_TAKE_PAYMENT', False)
        # If `PLACE_ORDER_BEFORE_TAKE_PAYMENT` is set to True, you might want yo define a
        # status for such order.
        self.ORDER_STATUS_BEFORE_PAYMENT = getattr(settings, 'ORDER_STATUS_BEFORE_PAYMENT', _(u"Pending payment"))

        self.WEBPAY_RETURN_IP_ADDRESS = getattr(settings, 'WEBPAY_RETURN_IP_ADDRESS', '127.0.0.1')
        self.WEBPAY_RETURN_PORT = getattr(settings, 'WEBPAY_RETURN_PORT', 80)
        self.WEBPAY_CERT_DIR = getattr(settings, 'WEBPAY_CERT_DIR', os.path.join(settings.BASE_DIR,
                                                                                 'webpay_certificates'))
        self.WEBPAY_ENABLED_MODES = getattr(settings, 'WEBPAY_ENABLED_MODES', ['NORMAL'])
        self.__webpay_modes = ['NORMAL', 'NORMAL_MALL', 'CAPTURE', 'ONECLICK', 'COMPLETE', 'NULLIFY']
        self.__conf_required_data = [
            'ACTIVE_ENVIRON',   # Use mode (INTEGRATION, CERTIFICATION o PRODUCTION).
            'ENVIRONMENTS',     # Dictionary, keys are environment and values are the WSDL values.
            'PRIVATE_KEY',      # Private key, absolute path.
            'PUBLIC_CERT',      # Public certificate, absolute path.
            'WEBPAY_CERT',      # Private cert, absolute path.
            'COMMERCE_CODE',    # Well ...   Commerce code ;)
        ]

        for mode in self.WEBPAY_ENABLED_MODES:
            if mode in self.__webpay_modes:
                webpay_mode = getattr(settings, 'WEBPAY_{}'.format(mode), None)
                if webpay_mode is None:
                    error_msg = _(u'You must set the configuration for all the enabled webpay modes\n' \
                                  u'Please configure WEBPAY_{} setting\'s variable.'.format(mode))
                    logger.error(error_msg)
                    raise OscarWebpaySettingError(error_msg)
                else:
                    setattr(self, 'WEBPAY_{}'.format(mode), webpay_mode)

                # Check all the required data is set.
                for key in self.__conf_required_data:
                    if key not in webpay_mode.keys():
                        error_msg = _(u'WEBPAY_{} "{}" setting has not been set.').format(mode, key)
                        logger.error(error_msg)
                        raise OscarWebpaySettingError(error_msg)
            else:
                error_msg = _(u'Oscar webpay do not support this mode: {}'.format(mode))
                logger.error(error_msg)
                raise OscarWebpaySettingError(error_msg)


class OscarWebpayLazySettings(LazyObject):

    def _setup(self, name=None):
        self._wrapped = OscarWebpaySettings()


oscar_webpay_settings = OscarWebpayLazySettings()



from oscar_webpay.libwebpay.webpay import Webpay
from oscar_webpay.certificates import cert_normal
from oscar_webpay.libwebpay.configuration import Configuration

from oscar_webpay.oscar_webpay_settings import oscar_webpay_settings
from oscar_webpay.exceptions import \
    AuthenticationError, \
    FailedTransaction, \
    AbortedTransactionByCardHolder, \
    TimeLimitExceeded, \
    U3Exception

from django.core.urlresolvers import reverse


def get_webpay_conf():
    certificate = cert_normal.certDictionary.dictionaryCert()
    configuration = Configuration()
    configuration.setEnvironment(certificate['environment'])
    configuration.setCommerceCode(certificate['commerce_code'])
    configuration.setPrivateKey(certificate['private_key'])
    configuration.setPublicCert(certificate['public_cert'])
    configuration.setWebpayCert(certificate['webpay_cert'])
    return configuration


def get_webpay_client(order_number, total):

    webpay = Webpay(get_webpay_conf())

    amount = total
    buy_order = order_number
    session_id = None

    final_url = 'http://{}:{}{}'.format(
        oscar_webpay_settings.WEBPAY_RETURN_IP_ADDRESS,
        oscar_webpay_settings.WEBPAY_RETURN_PORT,
        reverse('webpay-end-redirect')
    )

    return_url = 'http://{}:{}{}'.format(
        oscar_webpay_settings.WEBPAY_RETURN_IP_ADDRESS,
        oscar_webpay_settings.WEBPAY_RETURN_PORT,
        reverse('webpay-success')
    )

    initTransactionOutput = webpay.getNormalTransaction().initTransaction(amount, buy_order, session_id, return_url, final_url)
    return initTransactionOutput


def confirm_transaction(token):
    webpay = Webpay(get_webpay_conf())
    result = webpay.getNormalTransaction().getTransaction(token)

    if result.VCI == 'TSY':
        # Successful transaction.
        pass

    if result.VCI == 'TSN':
        raise FailedTransaction(result)

    if result.VCI == 'TO':
        # Time limit exceeeded.
        raise TimeLimitExceeded

    if result.VCI == 'ABO':
        # Failed transaction.
        raise AbortedTransactionByCardHolder

    if result.VCI == 'U3':
        # Internal authentication error.
        raise U3Exception

    return result

def  acknowledge_transaction(token):
    webpay = Webpay(get_webpay_conf())
    result = webpay.getNormalTransaction().acknowledgeTransaction(token)
    return  result





import os
import logging
from oscar.defaults import OSCAR_DASHBOARD_NAVIGATION

from django.utils.translation import ugettext_lazy as _


logger = logging.getLogger('oscar_webpay')


OSCAR_DASHBOARD_NAVIGATION += (
    {
        'label': _('WebPay'),
        'icon': 'icon-globe',
        'children': [
            {
                'label': _('WebPay transactions'),
                'url_name': 'webpay-transaction-list',
            },
        ]
    },
)


from setuptools import setup
from os import path

here = path.abspath(path.dirname(__file__))


long_description = ''

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except(IOError, ImportError):
    long_description = ''

setup(
    name='django-oscar-webpay',

    version='0.2.1',

    description='An application for intagrating WebPay with oscar based e-commerce sites',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/RaydelMiranda/django-oscar-webpay',

    # Author details
    author='Raydel Miranda',
    author_email='raydel.miranda.gomez@gmail.com',

    license='LGPL',
    data_files=[('', ['README.md'])],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development',
        'Environment :: Web Environment',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='development web django webpay ecommerce',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=['oscar_webpay', 'oscar_webpay.certificates', 'oscar_webpay.libwebpay'],

    install_requires=['suds==0.4', 'py-wsse==0.1'],
)